@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     AggregationTypeType,
@@ -376,20 +376,20 @@ ConnectorProfileCredentialsTypeDef = TypedDict(
 ConnectorProfilePropertiesTypeDef = TypedDict(
     "ConnectorProfilePropertiesTypeDef",
     {
-        "Amplitude": Dict[str, Any],
+        "Amplitude": Mapping[str, Any],
         "Datadog": "DatadogConnectorProfilePropertiesTypeDef",
         "Dynatrace": "DynatraceConnectorProfilePropertiesTypeDef",
-        "GoogleAnalytics": Dict[str, Any],
-        "Honeycode": Dict[str, Any],
+        "GoogleAnalytics": Mapping[str, Any],
+        "Honeycode": Mapping[str, Any],
         "InforNexus": "InforNexusConnectorProfilePropertiesTypeDef",
         "Marketo": "MarketoConnectorProfilePropertiesTypeDef",
         "Redshift": "RedshiftConnectorProfilePropertiesTypeDef",
         "Salesforce": "SalesforceConnectorProfilePropertiesTypeDef",
         "ServiceNow": "ServiceNowConnectorProfilePropertiesTypeDef",
-        "Singular": Dict[str, Any],
+        "Singular": Mapping[str, Any],
         "Slack": "SlackConnectorProfilePropertiesTypeDef",
         "Snowflake": "SnowflakeConnectorProfilePropertiesTypeDef",
-        "Trendmicro": Dict[str, Any],
+        "Trendmicro": Mapping[str, Any],
         "Veeva": "VeevaConnectorProfilePropertiesTypeDef",
         "Zendesk": "ZendeskConnectorProfilePropertiesTypeDef",
         "SAPOData": "SAPODataConnectorProfilePropertiesTypeDef",
@@ -452,8 +452,8 @@ _RequiredCreateFlowRequestRequestTypeDef = TypedDict(
         "flowName": str,
         "triggerConfig": "TriggerConfigTypeDef",
         "sourceFlowConfig": "SourceFlowConfigTypeDef",
-        "destinationFlowConfigList": List["DestinationFlowConfigTypeDef"],
-        "tasks": List["TaskTypeDef"],
+        "destinationFlowConfigList": Sequence["DestinationFlowConfigTypeDef"],
+        "tasks": Sequence["TaskTypeDef"],
     },
 )
 _OptionalCreateFlowRequestRequestTypeDef = TypedDict(
@@ -461,7 +461,7 @@ _OptionalCreateFlowRequestRequestTypeDef = TypedDict(
     {
         "description": str,
         "kmsArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -603,7 +603,7 @@ DescribeConnectorEntityResponseTypeDef = TypedDict(
 DescribeConnectorProfilesRequestRequestTypeDef = TypedDict(
     "DescribeConnectorProfilesRequestRequestTypeDef",
     {
-        "connectorProfileNames": List[str],
+        "connectorProfileNames": Sequence[str],
         "connectorType": ConnectorTypeType,
         "maxResults": int,
         "nextToken": str,
@@ -623,7 +623,7 @@ DescribeConnectorProfilesResponseTypeDef = TypedDict(
 DescribeConnectorsRequestRequestTypeDef = TypedDict(
     "DescribeConnectorsRequestRequestTypeDef",
     {
-        "connectorTypes": List[ConnectorTypeType],
+        "connectorTypes": Sequence[ConnectorTypeType],
         "nextToken": str,
     },
     total=False,
@@ -708,7 +708,7 @@ DestinationConnectorPropertiesTypeDef = TypedDict(
         "Salesforce": "SalesforceDestinationPropertiesTypeDef",
         "Snowflake": "SnowflakeDestinationPropertiesTypeDef",
         "EventBridge": "EventBridgeDestinationPropertiesTypeDef",
-        "LookoutMetrics": Dict[str, Any],
+        "LookoutMetrics": Mapping[str, Any],
         "Upsolver": "UpsolverDestinationPropertiesTypeDef",
         "Honeycode": "HoneycodeDestinationPropertiesTypeDef",
         "CustomerProfiles": "CustomerProfilesDestinationPropertiesTypeDef",
@@ -1115,7 +1115,7 @@ OAuthPropertiesTypeDef = TypedDict(
     {
         "tokenUrl": str,
         "authCodeUrl": str,
-        "oAuthScopes": List[str],
+        "oAuthScopes": Sequence[str],
     },
 )
 
@@ -1330,7 +1330,7 @@ _RequiredSalesforceDestinationPropertiesTypeDef = TypedDict(
 _OptionalSalesforceDestinationPropertiesTypeDef = TypedDict(
     "_OptionalSalesforceDestinationPropertiesTypeDef",
     {
-        "idFieldNames": List[str],
+        "idFieldNames": Sequence[str],
         "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
         "writeOperationType": WriteOperationTypeType,
     },
@@ -1644,14 +1644,14 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
 _RequiredTaskTypeDef = TypedDict(
     "_RequiredTaskTypeDef",
     {
-        "sourceFields": List[str],
+        "sourceFields": Sequence[str],
         "taskType": TaskTypeType,
     },
 )
@@ -1660,7 +1660,7 @@ _OptionalTaskTypeDef = TypedDict(
     {
         "connectorOperator": "ConnectorOperatorTypeDef",
         "destinationField": str,
-        "taskProperties": Dict[OperatorPropertiesKeysType, str],
+        "taskProperties": Mapping[OperatorPropertiesKeysType, str],
     },
     total=False,
 )
@@ -1715,7 +1715,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -1742,8 +1742,8 @@ _RequiredUpdateFlowRequestRequestTypeDef = TypedDict(
         "flowName": str,
         "triggerConfig": "TriggerConfigTypeDef",
         "sourceFlowConfig": "SourceFlowConfigTypeDef",
-        "destinationFlowConfigList": List["DestinationFlowConfigTypeDef"],
-        "tasks": List["TaskTypeDef"],
+        "destinationFlowConfigList": Sequence["DestinationFlowConfigTypeDef"],
+        "tasks": Sequence["TaskTypeDef"],
     },
 )
 _OptionalUpdateFlowRequestRequestTypeDef = TypedDict(
@@ -1892,7 +1892,7 @@ _RequiredZendeskDestinationPropertiesTypeDef = TypedDict(
 _OptionalZendeskDestinationPropertiesTypeDef = TypedDict(
     "_OptionalZendeskDestinationPropertiesTypeDef",
     {
-        "idFieldNames": List[str],
+        "idFieldNames": Sequence[str],
         "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
         "writeOperationType": WriteOperationTypeType,
     },
